"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryLoadProjectVersion = void 0;
const path_1 = __importDefault(require("path"));
const ts_results_es_1 = require("ts-results-es");
const common_errors_1 = require("../common-errors");
const file_io_1 = require("./file-io");
const string_parsing_1 = require("../utils/string-parsing");
function projectVersionTxtPathFor(projectDirPath) {
    return path_1.default.join(projectDirPath, "ProjectSettings", "ProjectVersion.txt");
}
/**
 * Attempts to load a projects editor-version from ProjectVersion.txt.
 * @param projectDirPath The path to the projects root directory.
 */
function tryLoadProjectVersion(projectDirPath) {
    const filePath = projectVersionTxtPathFor(projectDirPath);
    return (0, file_io_1.tryReadTextFromFile)(filePath)
        .andThen(string_parsing_1.tryParseYaml)
        .andThen((content) => {
        if (!(typeof content === "object" &&
            content !== null &&
            "m_EditorVersion" in content &&
            typeof content.m_EditorVersion === "string"))
            return (0, ts_results_es_1.Err)(new common_errors_1.FileParseError(filePath, "Project-version"));
        return (0, ts_results_es_1.Ok)(content.m_EditorVersion);
    });
}
exports.tryLoadProjectVersion = tryLoadProjectVersion;
//# sourceMappingURL=project-version-io.js.map